==> crm-commom-1.1.9.11.release.jar: com/biz/crm/aop/WebLogAspect.java <==
package com.biz.crm.aop;

import com.alibaba.fastjson.JSONArray;
import com.biz.crm.util.StringUtils;
import com.biz.crm.util.UserRedis;
import com.biz.crm.util.UserUtils;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.lang.reflect.Method;
import java.util.Optional;

import static jodd.net.MimeTypes.MIME_APPLICATION_JSON;

/**
 * @author zxw
 */
@Aspect
@Component
@Slf4j
public class WebLogAspect {


    public WebLogAspect() {
    }


    /**
     * 前置通知：
     * 1. 在执行目标方法之前执行，比如请求接口之前的登录验证;
     * 2. 在前置通知中设置请求日志信息，如开始时间，请求参数，注解内容等
     */
    @Before("@annotation(CrmLog) || @within(CrmGlobalLog)")
    public void doBefore(JoinPoint joinPoint) {
        ServletRequestAttributes requestAttributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if (requestAttributes != null) {
            HttpServletRequest request = requestAttributes.getRequest();
            String contentType = request.getContentType();
            if (MIME_APPLICATION_JSON.equals(contentType)) {
                Class<?> clazz = joinPoint.getTarget().getClass();
                Method method = ((MethodSignature) joinPoint.getSignature()).getMethod();
                ApiOperation apiOperation = method.getAnnotation(ApiOperation.class);
                log.info("------------------------------------------AOP日志start--------------------------------------------------------");
                log.info("[AOP日志]:类名:{}", clazz.getName());
                Optional.ofNullable(apiOperation)
                        .filter(x -> !StringUtils.isEmpty(x.value()))
                        .ifPresent(x -> log.info("[AOP日志]:apiOperation注释:{}", x.value()));
                log.info("[AOP日志]:方法名:{}", method.getName());
                Optional.ofNullable(joinPoint.getArgs()).ifPresent(x -> {
                    for (Object arg : x) {
                        if (arg instanceof HttpServletRequest || arg instanceof HttpServletResponse) {
                            continue;
                        }
                        log.info("[AOP日志]:方法入参:{}", JSONArray.toJSONString(x));
                    }
                });
                UserRedis user = UserUtils.getUser();
                log.info("[AOP日志]:请求用户:{}", user);
                log.info("------------------------------------------AOP日志end--------------------------------------------------------");
            }
        }


    }

//    /**
//     * 返回通知：
//     * 1. 在目标方法正常结束之后执行
//     * 1. 在返回通知中补充请求日志信息，如返回时间，方法耗时，返回值，并且保存日志信息
//     *
//     * @param ret
//     * @throws Throwable
//     */
//    @AfterReturning(returning = "ret", pointcut = "webLogPointcut()")
//    public void doAfterReturning(Object ret) throws Throwable {
//    }

//    /**
//     * 异常通知：
//     * 1. 在目标方法非正常结束，发生异常或者抛出异常时执行
//     * 1. 在异常通知中设置异常信息，并将其保存
//     *
//     * @param throwable
//     */
//    @AfterThrowing(value = "webLogPointcut()", throwing = "throwable")
//    public void doAfterThrowing(Throwable throwable) {
//        // 保存异常日志记录
//        log.error("发生异常时间：{}" + LocalDateTime.now());
//        log.error("抛出异常：{}" + throwable.getMessage());
//    }
}

==> crm-commom-1.1.9.21.release.jar: com/biz/crm/aop/WebLogAspect.java <==
package com.biz.crm.aop;

import com.alibaba.fastjson.JSONArray;
import com.biz.crm.util.StringUtils;
import com.biz.crm.util.UserRedis;
import com.biz.crm.util.UserUtils;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.lang.reflect.Method;
import java.util.Optional;

import static jodd.net.MimeTypes.MIME_APPLICATION_JSON;

/**
 * @author zxw
 */
@Aspect
@Component
@Slf4j
public class WebLogAspect {


    public WebLogAspect() {
    }


    /**
     * 前置通知：
     * 1. 在执行目标方法之前执行，比如请求接口之前的登录验证;
     * 2. 在前置通知中设置请求日志信息，如开始时间，请求参数，注解内容等
     */
    @Before("@annotation(CrmLog) || @within(CrmGlobalLog)")
    public void doBefore(JoinPoint joinPoint) {
        ServletRequestAttributes requestAttributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        if (requestAttributes != null) {
            HttpServletRequest request = requestAttributes.getRequest();
            String contentType = request.getContentType();
            if (MIME_APPLICATION_JSON.equals(contentType)) {
                Class<?> clazz = joinPoint.getTarget().getClass();
                Method method = ((MethodSignature) joinPoint.getSignature()).getMethod();
                ApiOperation apiOperation = method.getAnnotation(ApiOperation.class);
                log.info("------------------------------------------AOP日志start--------------------------------------------------------");
                log.info("[AOP日志]:类名:{}", clazz.getName());
                Optional.ofNullable(apiOperation)
                        .filter(x -> !StringUtils.isEmpty(x.value()))
                        .ifPresent(x -> log.info("[AOP日志]:apiOperation注释:{}", x.value()));
                log.info("[AOP日志]:方法名:{}", method.getName());
                Optional.ofNullable(joinPoint.getArgs()).ifPresent(x -> {
                    for (Object arg : x) {
//                        if (arg instanceof HttpServletRequest || arg instanceof HttpServletResponse) {
//                            continue;
//                        }
                        log.info("[AOP日志]:方法入参:{}", JSONArray.toJSONString(x));
                    }
                });
                UserRedis user = UserUtils.getUser();
                log.info("[AOP日志]:请求用户:{}", user);
                log.info("------------------------------------------AOP日志end--------------------------------------------------------");
            }
        }


    }

//    /**
//     * 返回通知：
//     * 1. 在目标方法正常结束之后执行
//     * 1. 在返回通知中补充请求日志信息，如返回时间，方法耗时，返回值，并且保存日志信息
//     *
//     * @param ret
//     * @throws Throwable
//     */
//    @AfterReturning(returning = "ret", pointcut = "webLogPointcut()")
//    public void doAfterReturning(Object ret) throws Throwable {
//    }

//    /**
//     * 异常通知：
//     * 1. 在目标方法非正常结束，发生异常或者抛出异常时执行
//     * 1. 在异常通知中设置异常信息，并将其保存
//     *
//     * @param throwable
//     */
//    @AfterThrowing(value = "webLogPointcut()", throwing = "throwable")
//    public void doAfterThrowing(Throwable throwable) {
//        // 保存异常日志记录
//        log.error("发生异常时间：{}" + LocalDateTime.now());
//        log.error("抛出异常：{}" + throwable.getMessage());
//    }
}
